@@ -3,7 +3,7 @@ from .assets import Assets
 from .certificates import CertificatesAssets
 from .domains import DomainsAssets
 from .hosts import HostsAssets
-from .object_storage import ObjectStorageAssets
+from .object_storages import ObjectStoragesAssets
 from .subdomains import SubdomainsAssets
 from .web_entities import WebEntitiesAssets
 
@@ -12,7 +12,7 @@ __all__ = [
     "CertificatesAssets",
     "DomainsAssets",
     "HostsAssets",
-    "ObjectStorageAssets",
+    "ObjectStoragesAssets",
     "SubdomainsAssets",
     "WebEntitiesAssets",
 ]
