@@ -1,12 +1,11 @@
 """An easy-to-use and lightweight API wrapper for Censys Search API (search.censys.io)."""
 from .client import SearchClient
-from .v1 import CensysCertificates, CensysData
+from .v1 import CensysData
 from .v2 import CensysCerts, CensysHosts
 
-__copyright__ = "Copyright 2022 Censys, Inc."
+__copyright__ = "Copyright 2024 Censys, Inc."
 __all__ = [
     "SearchClient",
-    "CensysCertificates",
     "CensysData",
     "CensysCerts",
     "CensysHosts",
