@@ -259,7 +259,7 @@ class CensysHosts(CensysSearchAPIv2):
         per_page: Optional[int] = None,
         cursor: Optional[str] = None,
         reversed: Optional[bool] = None,
-    ) -> List[dict]:
+    ) -> dict:
         """Fetches a list of events for the specified IP address.
 
         Args:
@@ -275,7 +275,7 @@ class CensysHosts(CensysSearchAPIv2):
                 that is, return events in reversed chronological order.
 
         Returns:
-            List[dict]: A list of events.
+            dict: A list of events.
         """
         args = {"per_page": per_page, "cursor": cursor, "reversed": reversed}
         if start_time:
@@ -285,7 +285,31 @@ class CensysHosts(CensysSearchAPIv2):
 
         return self._get(f"/v2/experimental/{self.INDEX_NAME}/{ip}/events", args)[
             "result"
-        ]["events"]
+        ]
+
+    def view_host_certificates(
+        self,
+        ip: str,
+        per_page: int = 100,
+        start_time: Optional[Datetime] = None,
+        cursor: Optional[str] = None,
+    ) -> dict:
+        """Returns a list of certificates for the specified host.
+
+        Args:
+            ip (str): The IP address of the requested host.
+            per_page (int): Optional; The number of results to be returned for each page. Defaults to 100.
+            start_time (Datetime): Optional; An RFC3339 timestamp which represents
+                the beginning chronological point-in-time (inclusive) from which events are returned.
+            cursor (str): Optional; Cursor token from the API response.
+
+        Returns:
+            dict: A list of certificates.
+        """
+        args = {"per_page": per_page, "cursor": cursor}
+        if start_time:
+            args["start_time"] = format_rfc3339(start_time)
+        return self._get(f"/v2/{self.INDEX_NAME}/{ip}/certificates", args)["result"]
 
     def list_hosts_with_tag(self, tag_id: str) -> List[str]:
         """Returns a list of hosts which are tagged with the specified tag.
